==> groupsms_0.1.2.tar.gz: groupsms-0.1.2/groupsms_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="aboutwindow.ui" line="14"/>
        <source>Group SMS - About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="aboutwindow.cpp" line="33"/>
        <source>Back</source>
        <translation type="unfinished">Indietro</translation>
    </message>
</context>
<context>
    <name>ContactsWindow</name>
    <message>
        <location filename="contactswindow.ui" line="14"/>
        <source>Address book</source>
        <translation type="unfinished">Rubrica</translation>
    </message>
    <message>
        <location filename="contactswindow.ui" line="32"/>
        <source>Find:</source>
        <translation type="unfinished">Cerca:</translation>
    </message>
    <message>
        <location filename="contactswindow.cpp" line="36"/>
        <source>Back</source>
        <translation type="unfinished">Indietro</translation>
    </message>
    <message>
        <location filename="contactswindow.cpp" line="86"/>
        <location filename="contactswindow.cpp" line="154"/>
        <source>Address book (%1)</source>
        <translation type="unfinished">Rubrica (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWindow</name>
    <message>
        <location filename="editgroupwindow.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editgroupwindow.ui" line="47"/>
        <source>Name:</source>
        <translation type="unfinished">Nome:</translation>
    </message>
    <message>
        <location filename="editgroupwindow.ui" line="61"/>
        <source>Save</source>
        <translation type="unfinished">Salva</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="33"/>
        <source>Edit group</source>
        <translation type="unfinished">Modifica Gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="35"/>
        <source>New group</source>
        <translation type="unfinished">Nuovo Gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="53"/>
        <source>Enter a group name</source>
        <translation type="unfinished">Inserisci il nome del gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="59"/>
        <source>A group named &apos;%1&apos; exists.</source>
        <translation type="unfinished">Un gruppo chiamato &apos;%1&apos; esiste già.</translation>
    </message>
</context>
<context>
    <name>GroupActionsWindow</name>
    <message>
        <location filename="groupactionswindow.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="129"/>
        <source>Confirm remove</source>
        <translation type="unfinished">Conferma rimozione</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="130"/>
        <source>Remove %1 contacts from group %2?</source>
        <translation type="unfinished">Rimuovere %1 contatti dal gruppo %2?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="27"/>
        <source>Add new group</source>
        <translation type="unfinished">Aggiungi gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="43"/>
        <source>Group SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="44"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="48"/>
        <source>Exit</source>
        <translation type="unfinished">Esci</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="commonstatic.cpp" line="34"/>
        <source>Confirm</source>
        <translation type="unfinished">Conferma</translation>
    </message>
</context>
</TS>

==> groupsms_0.1.6.tar.gz: groupsms-0.1.6/groupsms_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="aboutwindow.ui" line="14"/>
        <source>Group SMS - About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="aboutwindow.cpp" line="33"/>
        <source>Back</source>
        <translation type="unfinished">Indietro</translation>
    </message>
</context>
<context>
    <name>ContactsWindow</name>
    <message>
        <location filename="contactswindow.ui" line="14"/>
        <source>Address book</source>
        <translation type="unfinished">Rubrica</translation>
    </message>
    <message>
        <location filename="contactswindow.ui" line="32"/>
        <source>Find:</source>
        <translation type="unfinished">Cerca:</translation>
    </message>
    <message>
        <location filename="contactswindow.cpp" line="36"/>
        <source>Back</source>
        <translation type="unfinished">Indietro</translation>
    </message>
    <message>
        <location filename="contactswindow.cpp" line="88"/>
        <location filename="contactswindow.cpp" line="156"/>
        <source>Address book (%1)</source>
        <translation type="unfinished">Rubrica (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWindow</name>
    <message>
        <location filename="editgroupwindow.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editgroupwindow.ui" line="47"/>
        <source>Name:</source>
        <translation type="unfinished">Nome:</translation>
    </message>
    <message>
        <location filename="editgroupwindow.ui" line="61"/>
        <source>Save</source>
        <translation type="unfinished">Salva</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="34"/>
        <source>Edit group</source>
        <translation type="unfinished">Modifica Gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="36"/>
        <source>New group</source>
        <translation type="unfinished">Nuovo Gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="54"/>
        <source>Enter a group name</source>
        <translation type="unfinished">Inserisci il nome del gruppo</translation>
    </message>
    <message>
        <location filename="editgroupwindow.cpp" line="60"/>
        <source>A group named &apos;%1&apos; exists.</source>
        <translation type="unfinished">Un gruppo chiamato &apos;%1&apos; esiste già.</translation>
    </message>
</context>
<context>
    <name>GroupActionsWindow</name>
    <message>
        <location filename="groupactionswindow.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="45"/>
        <source>Select all</source>
        <translation type="unfinished">Seleziona tutti</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="48"/>
        <source>Deselect all</source>
        <translation type="unfinished">Deseleziona tutti</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="51"/>
        <source>Remove contact</source>
        <translation type="unfinished">Rimuovi contatto</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="147"/>
        <location filename="groupactionswindow.cpp" line="252"/>
        <source>Confirm remove</source>
        <translation type="unfinished">Conferma rimozione</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="148"/>
        <source>Remove %1 contacts from group %2?</source>
        <translation type="unfinished">Rimuovere %1 contatti dal gruppo %2?</translation>
    </message>
    <message>
        <location filename="groupactionswindow.cpp" line="253"/>
        <source>Remove 1 contact from group %1?</source>
        <oldsource>Remove 1 contact from group %2?</oldsource>
        <translation type="unfinished">Rimuovere 1 contatto dal gruppo %1?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="27"/>
        <source>Add new group</source>
        <translation type="unfinished">Aggiungi gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="46"/>
        <source>Group SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="47"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="51"/>
        <source>Exit</source>
        <translation type="unfinished">Esci</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="58"/>
        <source>Remove group</source>
        <translation type="unfinished">Cancella gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="61"/>
        <source>Send SMS to group</source>
        <translation type="unfinished">Invia SMS al gruppo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="232"/>
        <source>Confirm remove</source>
        <translation type="unfinished">Conferma rimozione</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="233"/>
        <source>Remove group %1?</source>
        <translation type="unfinished">Rimuovere il gruppo %1?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="commonstatic.cpp" line="34"/>
        <source>Confirm</source>
        <translation type="unfinished">Conferma</translation>
    </message>
</context>
</TS>
